@@ -133,7 +133,12 @@ fluidPage(
 
               selectInput('tableposition','Table Position:',
                           c("on the right" = "right", "below" = "below", "none" = "none") ),
-              checkboxInput('showtablefacetstrips', 'Show Table Facet Strip ?', value = FALSE),
+              selectInput(  "showtablefacetstrips", "Show Table Facet Strip on:",
+                            choices = c("none","both","y","x"),
+                            selected = c("none"),
+                            multiple = FALSE),
+              checkboxInput('showtableyaxisticklabel', 'Show Table y axis ticks/labels ?', value = FALSE),
+              
 
               hr(),
               checkboxInput('showrefarea', 'Show Reference Area?', value = TRUE),
@@ -151,20 +156,20 @@ fluidPage(
           colourpicker::colourInput("stripbackgroundfill",
                                     "Strip Background Fill:",
                                     value="#E5E5E5",
-                                    showColour = "both",allowTransparent=TRUE),
+                                    showColour = "both",allowTransparent=TRUE, returnName = TRUE),
           div( actionButton("stripbackfillreset", "Reset Strip Background Fill"),
                style="text-align: right"),
           colourpicker::colourInput("colourpointrange",
                                     "Point Range Colour:",
                                     value="blue",
-                                    showColour = "both",allowTransparent=TRUE),
+                                    showColour = "both",allowTransparent=TRUE, , returnName = TRUE),
           div( actionButton("colourpointrangereset", "Reset Point Range Colour"),
                style="text-align: right"),
 
           colourpicker::colourInput("fillrefarea",
                                     "Reference Area Fill:",
                                     value= "#BEBEBE50",
-                                    showColour = "both",allowTransparent=TRUE),
+                                    showColour = "both",allowTransparent=TRUE, , returnName = TRUE),
           div( actionButton("fillrefareareset", "Reset Reference Area Fill"),
                style="text-align: right"),
           sliderInput("legendspacex", "Multiplier for Space between Legends",
